@@ -3,52 +3,32 @@ u"""Классы для работы первично отображаемого
 
 Включают список модулей в меню "Пуск" и список модулей на "Рабочем столе"
 """
+from __future__ import absolute_import
+
+from importlib import import_module
+from logging import getLogger
+from uuid import uuid4
+import itertools
 import threading
-import six
 import warnings
-from logging import (
-    getLogger,
-)
-from uuid import (
-    uuid4,
-)
 
-from six.moves import (
-    filter,
-    map,
-)
-
-from m3 import (
-    M3JSONEncoder,
-)
-from m3.actions import (
-    Action,
-    ControllerCache,
-)
-from m3.plugins import (
-    get_and_execute_callable_from_modules,
-)
-
-from .signals import (
-    desktop_loader_after_populate,
-)
+from django.conf import settings
+from m3 import M3JSONEncoder
+from m3.actions import Action
+from m3.actions import ControllerCache
+from m3_django_compat import get_installed_apps
+import six
+from six.moves import map
+from six.moves import filter
 
 
 logger = getLogger('django')
 
 
 try:
-    from m3_users.app_meta import (
-        GENERIC_USER,
-        SUPER_ADMIN,
-    )
-    from m3_users.helpers import (
-        get_assigned_metaroles_query,
-    )
-    from m3_users.metaroles import (
-        UserMetarole,
-        get_metarole,
-    )
+    from m3_users.app_meta import GENERIC_USER, SUPER_ADMIN
+    from m3_users.helpers import get_assigned_metaroles_query
+    from m3_users.metaroles import UserMetarole, get_metarole
 except ImportError:
     # если не установлен пакет m3_users
     # Всё должно работать без метаролей
@@ -369,8 +349,21 @@ class DesktopLoader(object):
                 cls._cache = {}
                 # Из инитов всех приложения
                 # пытаемся выполнить register_desktop_menu
-                get_and_execute_callable_from_modules('app_meta', 'register_desktop_menu')
-
+                for app_name in get_installed_apps():
+                    try:
+                        module = import_module('.app_meta', app_name)
+                    except ImportError as err:
+                        if err.args[0].find('No module named') == -1 or (
+                                err.args[0].find('app_meta') == -1):
+                            logger.exception(
+                                u'При сборке интерфейса не удалось '
+                                u'подключить %s', app_name
+                            )
+                            raise
+                        continue
+                    proc = getattr(module, 'register_desktop_menu', None)
+                    if callable(proc):
+                        proc()
             cls._success = True
         finally:
             cls._lock.release()
@@ -450,9 +443,7 @@ class DesktopLoader(object):
         :param sorting: функция сортировки
         :type sorting: callable
         """
-        from django.contrib.auth.models import (
-            AnonymousUser,
-        )
+        from django.contrib.auth.models import AnonymousUser
 
         roles = []
         if not isinstance(user, AnonymousUser):
@@ -461,7 +452,6 @@ class DesktopLoader(object):
                 roles.append(SUPER_ADMIN)
 
         cls.populate_desktop(desktop, roles, sorting)
-        desktop_loader_after_populate.send(sender=cls)
 
     @classmethod
     def populate_desktop(cls, desktop, roles=None, sorting=DEFAULT_SORTING):
